@@ -20,7 +20,7 @@ cities_table <- aq_cities()
 kable(head(cities_table))
 
 ## ---- cache=FALSE--------------------------------------------------------
-cities_tableIndia <- aq_cities(country="IN", limit = 10)
+cities_tableIndia <- aq_cities(country="IN", limit = 10, page = 1)
 kable(cities_tableIndia)
 
 ## ---- error=TRUE---------------------------------------------------------
@@ -31,31 +31,13 @@ locations_chennai <- aq_locations(country = "IN", city = "Chennai", parameter =
 kable(locations_chennai)
 
 ## ---- cache=FALSE--------------------------------------------------------
-results_table <- aq_measurements(country = "IN", city = "Delhi", location = "Anand+Vihar", parameter = "pm25")
-kable(head(results_table))
+results_table <- aq_measurements(country = "IN", city = "Delhi", parameter = "pm25", limit = 10, page = 1)
+kable(results_table)
 
 ## ---- cache=FALSE--------------------------------------------------------
-tableLatest <- aq_latest()
+tableLatest <- aq_latest(country="IN", city="Hyderabad")
 kable(head(tableLatest))
 
-## ---- cache=FALSE--------------------------------------------------------
-tableLatest <- aq_latest(country="IN", city="Delhi", location="Anand+Vihar")
-kable(head(tableLatest))
-
-## ------------------------------------------------------------------------
-how_many <- attr(aq_measurements(city = "Delhi",
-                            parameter = "pm25"), "meta")
-knitr::kable(how_many)
-how_many$found
-
 ## ---- eval = FALSE-------------------------------------------------------
-#  meas <- NULL
-#  for (page in 1:(ceiling(how_many$found/1000))){
-#    meas <- dplyr::bind_rows(meas,
-#                  aq_measurements(city = "Delhi",
-#                                  parameter = "pm25",
-#                                  page = page,
-#                                  limit = 1000))
-#    }
-#  
+#  aq_measurements(city = "Delhi", parameter = "pm25")
 
