@@ -1,10 +1,10 @@
 ## ---- echo = FALSE, warning=FALSE, message=FALSE-------------------------
-NOT_CRAN <- !identical(tolower(Sys.getenv("NOT_CRAN")), "true")
+NOT_CRAN <- identical(tolower(Sys.getenv("NOT_CRAN")), "true")
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
-  purl = TRUE,
-  eval = TRUE
+  purl = NOT_CRAN,
+  eval = NOT_CRAN
 )
 
 ## ---- warning=FALSE, message=FALSE---------------------------------------
@@ -15,8 +15,8 @@ library("dplyr")
 
 ## ------------------------------------------------------------------------
 measurementsNL <- aq_measurements(location="Amsterdam-Einsteinweg", parameter="pm25",
-                                       date_from="2015-09-01",
-                                       date_to="2015-12-31")
+                                       date_from = as.character(Sys.Date() - 100),
+                                       date_to = as.character(Sys.Date()))
 
 # filter negative values
 # and rename columns for compatibilities with openair
@@ -31,11 +31,18 @@ measurementsNL <- as.data.frame(measurementsNL)
 
 ## ---- fig.width=7, fig.height=4------------------------------------------
 # useful timeplot
-timePlot(mydata=measurementsNL, pollutant = "pm25")
+timePlot(mydata = measurementsNL, pollutant = "pm25")
 
 
 ## ---- fig.width=7, fig.height=4------------------------------------------
-# cool calendar plot
-calendarPlot(mydata=measurementsNL, pollutant = "pm25", year =2015)
+# cool calendar plot 
+if(as.numeric(format(Sys.Date(), "%m")) < 2){
+  calendarPlot(mydata=measurementsNL, pollutant = "pm25",
+             year = as.numeric(format(Sys.Date(), "%Y")) - 1)
+}else{
+  calendarPlot(mydata=measurementsNL, pollutant = "pm25",
+             year = as.numeric(format(Sys.Date(), "%Y")))
+}
+
 
 
